@@ -19,14 +19,14 @@ from keystoneauth1 import exceptions as ka_exc
 from keystoneauth1.identity import v2 as v2_auth
 from keystoneauth1.identity import v3 as v3_auth
 from keystoneauth1 import session
+from oslo_utils import importutils
 from oslo_utils import strutils
 import six.moves.urllib.parse as urlparse
 
-from ceilometerclient.common import utils
+from ceilometerclient.apiclient import auth
+from ceilometerclient.apiclient import client
+from ceilometerclient.apiclient import exceptions
 from ceilometerclient import exc
-from ceilometerclient.openstack.common.apiclient import auth
-from ceilometerclient.openstack.common.apiclient import client
-from ceilometerclient.openstack.common.apiclient import exceptions
 
 
 def _discover_auth_versions(session, auth_url):
@@ -87,13 +87,21 @@ def _get_keystone_session(**kwargs):
     # create the keystone client session
     ks_session = session.Session(verify=verify, cert=cert, timeout=timeout)
     v2_auth_url, v3_auth_url = _discover_auth_versions(ks_session, auth_url)
-
     username = kwargs.pop('username', None)
     user_id = kwargs.pop('user_id', None)
     user_domain_name = kwargs.pop('user_domain_name', None)
     user_domain_id = kwargs.pop('user_domain_id', None)
     project_domain_name = kwargs.pop('project_domain_name', None)
     project_domain_id = kwargs.pop('project_domain_id', None)
+    if v3_auth_url:
+        if not user_domain_id:
+            user_domain_id = 'default'
+        if not user_domain_name:
+            user_domain_name = 'default'
+        if not project_domain_id:
+            project_domain_id = 'default'
+        if not project_domain_name:
+            project_domain_name = 'default'
     auth = None
 
     use_domain = (user_domain_id or user_domain_name or
@@ -308,7 +316,8 @@ def _adjust_kwargs(kwargs):
 def Client(version, *args, **kwargs):
     client_kwargs = _adjust_kwargs(kwargs)
 
-    module = utils.import_versioned_module(version, 'client')
+    module = importutils.import_versioned_module('ceilometerclient',
+                                                 version, 'client')
     client_class = getattr(module, 'Client')
     return client_class(*args, **client_kwargs)
 
@@ -402,8 +411,9 @@ def _construct_http_client(**kwargs):
         # Drop legacy options
         for opt in LEGACY_OPTS:
             kwargs.pop(opt, None)
-        # Drop aodh_endpoint from kwargs
+        # Drop redirect endpoints from kwargs
         kwargs.pop('aodh_endpoint', None)
+        kwargs.pop('panko_endpoint', None)
 
         return SessionClient(
             session=kwargs.pop('session'),
